import React, { FunctionComponent, ButtonHTMLAttributes } from "react";
import styled from "@emotion/styled";
import { transparentize } from "polished";
import elevation from "../elevation";
import Box from "./Box";

/**
 * Button properties
 */
interface ButtonProps {
  /** Click handler */
  onClick?: () => void;
}

const StyledButton = styled(Box.withComponent("button"))(({ height }) => ({
  backgroundColor: "#334E68",
  boxShadow: `inset 0 1px 2px ${transparentize(0.6, "#F0F4F8")}, ${elevation(
    height
  )}`,
  color: "#F0F4F8",
  border: "none",
  borderRadius: 3,
  padding: "10px 30px",
  cursor: "pointer"
}));

/**
 * Button component
 */
const Button: FunctionComponent<ButtonProps> = function({ onClick, children }) {
  return (
    <StyledButton onClick={onClick} height={2}>
      {children}
    </StyledButton>
  );
};

export default Button;
